@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2019-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2019-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *
  *  Authors: Mickey Sola
  *
@@ -80,7 +80,7 @@ static cl_error_t onas_new_event_queue_node(struct onas_event_queue_node **node)
     return CL_SUCCESS;
 }
 
-static void *onas_init_event_queue()
+static void *onas_init_event_queue(void)
 {
 
     if (CL_EMEM == onas_new_event_queue_node(&g_onas_event_queue_head)) {
@@ -120,7 +120,7 @@ static void onas_destroy_event_queue_node(struct onas_event_queue_node *node)
     return;
 }
 
-static void onas_destroy_event_queue()
+static void onas_destroy_event_queue(void)
 {
 
     if (NULL == g_onas_event_queue_head) {
@@ -152,13 +152,12 @@ void *onas_scan_queue_th(void *arg)
 #elif defined(__APPLE__) && defined(__MACH__)
     pthread_setname_np(thread_name);
 #else
-    logg("^ClamScanQueue: Setting of the thread name is currently not supported on this system\n");
+    logg(LOGG_WARNING, "ClamScanQueue: Setting of the thread name is currently not supported on this system\n");
 #endif
 
     /* not a ton of use for context right now, but perhaps in the future we can pass in more options */
     struct onas_context *ctx = (struct onas_context *)arg;
     sigset_t sigset;
-    int ret;
 
     /* ignore all signals except SIGUSR2 */
     sigfillset(&sigset);
@@ -175,14 +174,14 @@ void *onas_scan_queue_th(void *arg)
 #endif
     pthread_sigmask(SIG_SETMASK, &sigset, NULL);
 
-    logg("*ClamScanQueue: initializing event queue consumer ... (%d) threads in thread pool\n", ctx->maxthreads);
+    logg(LOGG_DEBUG, "ClamScanQueue: initializing event queue consumer ... (%d) threads in thread pool\n", ctx->maxthreads);
     onas_init_event_queue();
     threadpool thpool = thpool_init(ctx->maxthreads);
     g_thpool          = thpool;
 
     /* loop w/ onas_consume_event until we die */
     pthread_cleanup_push(onas_scan_queue_exit, NULL);
-    logg("*ClamScanQueue: waiting to consume events ...\n");
+    logg(LOGG_DEBUG, "ClamScanQueue: waiting to consume events ...\n");
     do {
         onas_consume_event(thpool);
     } while (1);
@@ -190,7 +189,7 @@ void *onas_scan_queue_th(void *arg)
     pthread_cleanup_pop(1);
 }
 
-static int onas_queue_is_b_empty()
+static int onas_queue_is_b_empty(void)
 {
 
     if (g_onas_event_queue.head->next == g_onas_event_queue.tail) {
@@ -250,7 +249,7 @@ cl_error_t onas_scan_queue_start(struct onas_context **ctx)
     int32_t thread_started = 1;
 
     if (!ctx || !*ctx) {
-        logg("*ClamScanQueue: unable to start clamonacc. (bad context)\n");
+        logg(LOGG_DEBUG, "ClamScanQueue: unable to start clamonacc. (bad context)\n");
         return CL_EARG;
     }
 
@@ -262,7 +261,7 @@ cl_error_t onas_scan_queue_start(struct onas_context **ctx)
 
     if (0 != thread_started) {
         /* Failed to create thread */
-        logg("*ClamScanQueue: Unable to start event consumer queue thread ... \n");
+        logg(LOGG_DEBUG, "ClamScanQueue: Unable to start event consumer queue thread ... \n");
         return CL_ECREAT;
     }
 
@@ -273,12 +272,12 @@ static void onas_scan_queue_exit(void *arg)
 {
     UNUSEDPARAM(arg);
 
-    logg("*ClamScanQueue: onas_scan_queue_exit()\n");
+    logg(LOGG_DEBUG, "ClamScanQueue: onas_scan_queue_exit()\n");
     if (g_thpool) {
         thpool_wait(g_thpool);
         thpool_destroy(g_thpool);
         g_thpool = NULL;
     }
     onas_destroy_event_queue();
-    logg("ClamScanQueue: stopped\n");
+    logg(LOGG_INFO, "ClamScanQueue: stopped\n");
 }
