@@ -1,5 +1,8 @@
 /*
- *  Copyright (C) 2002, 2003 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
+ *
+ *  Authors: Tomasz Kojm
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -19,8 +22,8 @@
 #ifndef __MANAGER_H
 #define __MANAGER_H
 
-#include "shared/options.h"
+#include "optparser.h"
 
-int scanmanager(const struct optstruct *opt);
+int scanmanager(const struct optstruct *opts);
 
 #endif
