@@ -1,10 +1,10 @@
 /*
  *  JIT detection for ClamAV bytecode.
  *
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2010-2013 Sourcefire, Inc.
  *
- *  Authors: Török Edvin
+ *  Authors: Török Edvin, Andy Ragusa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -24,15 +24,11 @@
 #include "llvm/ADT/Triple.h"
 #include "llvm/Config/llvm-config.h"
 #include "llvm/Support/raw_ostream.h"
-#if LLVM_VERSION < 29
-#include "llvm/System/DataTypes.h"
-#include "llvm/System/Host.h"
-#include "llvm/System/Memory.h"
-#else
 #include "llvm/Support/DataTypes.h"
 #include "llvm/Support/Host.h"
 #include "llvm/Support/Memory.h"
-#endif
+
+#include "llvm/Support/Endian.h"
 
 extern "C" {
 #include "bytecode_detect.h"
@@ -56,27 +52,16 @@ static void warn_assumptions(const char *msg, int a, int b)
 
 void cli_detect_env_jit(struct cli_environment *env)
 {
-#if LLVM_VERSION < 31
-    std::string host_triple = sys::getHostTriple();
-#else
     std::string host_triple = sys::getDefaultTargetTriple();
-#endif
     INIT_STRFIELD(env->triple, host_triple.c_str());
 
-    std::string cpu = sys::getHostCPUName();
+    std::string cpu = sys::getHostCPUName().data();
     INIT_STRFIELD(env->cpu, cpu.c_str());
 
-#if LLVM_VERSION < 33
-    if (env->big_endian != (int)sys::isBigEndianHost()) {
-        warn_assumptions("host endianness", env->big_endian, sys::isBigEndianHost());
-        env->big_endian = sys::isBigEndianHost();
-    }
-#else
     if (env->big_endian != (int)sys::IsBigEndianHost) {
         warn_assumptions("host endianness", env->big_endian, sys::IsBigEndianHost);
         env->big_endian = sys::IsBigEndianHost;
     }
-#endif
 
 #ifdef __GNUC__
     env->cpp_version = MAKE_VERSION(0, __GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__);
@@ -121,11 +106,11 @@ void cli_detect_env_jit(struct cli_environment *env)
             if (env->arch != earch) {
                 /* bb #2153, bb #2214 */
                 /* configure can't detect -m32, so it thinks we are x86_64, when
-		 * in fact we are i386 only.
-		 * LLVM correctly detects which one it is using preprocessor
-		 * macros, so don't warn here, startup.cbc will just have to
-		 * rely on the LLVM provided info, and not the configure
-		 * provided one! */
+                 * in fact we are i386 only.
+                 * LLVM correctly detects which one it is using preprocessor
+                 * macros, so don't warn here, startup.cbc will just have to
+                 * rely on the LLVM provided info, and not the configure
+                 * provided one! */
                 if (env->arch != arch_i386)
                     conflicts = true;
             }
@@ -144,27 +129,17 @@ void cli_detect_env_jit(struct cli_environment *env)
     // OS
     Triple::OSType os = triple.getOS();
     switch (os) {
+        default: /*Treat unhandled cases as UnknownOS.*/
         case Triple::UnknownOS:
             env->os = llvm_os_UnknownOS;
             break;
-#if LLVM_VERSION < 36
-            CASE_OS(AuroraUX, os_solaris);
-            CASE_OS(Cygwin, os_win32);
-            CASE_OS(MinGW32, os_win32);
-#endif
             CASE_OS(Darwin, os_darwin);
             CASE_OS(DragonFly, os_bsd);
             CASE_OS(FreeBSD, os_bsd);
             CASE_OS(Linux, os_linux);
             CASE_OS(Lv2, os_unknown);
-#if LLVM_VERSION < 29
-            CASE_OS(MinGW64, os_win64);
-#endif
             CASE_OS(NetBSD, os_bsd);
             CASE_OS(OpenBSD, os_bsd);
-#if LLVM_VERSION < 31
-            CASE_OS(Psp, os_unknown);
-#endif
             CASE_OS(Solaris, os_solaris);
         case Triple::Win32:
             env->os = llvm_os_Win32;
@@ -177,12 +152,12 @@ void cli_detect_env_jit(struct cli_environment *env)
     }
 
     // mmap RWX
-    std::string ErrMsg;
-    sys::MemoryBlock B = sys::Memory::AllocateRWX(4096, NULL, &ErrMsg);
-    if (B.base() == 0) {
-        errs() << "LibClamAV Warning: RWX mapping denied: " << ErrMsg << "\n";
+    std::error_code ec;
+    sys::MemoryBlock memoryBlock = sys::Memory::allocateMappedMemory(4096, nullptr, sys::Memory::MF_READ | sys::Memory::MF_WRITE | sys::Memory::MF_EXEC, ec);
+    if (ec) {
+        errs() << "LibClamAV Warning: RWX mapping denied: " << ec.message() << "\n";
     } else {
         env->os_features |= 1 << feature_map_rwx;
-        sys::Memory::ReleaseRWX(B);
+        sys::Memory::releaseMappedMemory(memoryBlock);
     }
 }
