@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2009-2013 Sourcefire, Inc.
  *
  *  Authors: aCaB <acab@clamav.net>
@@ -37,6 +37,8 @@
 
 #include "clamav.h"
 
+#include "matcher-hash-types.h"
+
 struct cl_fmap;
 typedef cl_fmap_t fmap_t;
 
@@ -54,14 +56,14 @@ struct cl_fmap {
     uint64_t pgsz;
     uint64_t paged;
     uint16_t aging;
-    uint16_t dont_cache_flag; /** indicates if we should not cache scan results for this fmap. Used if limits exceeded */
-    uint16_t handle_is_fd;    /** non-zero if map->handle is an fd. */
-    size_t offset;            /** file offset representing start of original fmap, if the fmap created reading from a file starting at offset other than 0 */
-    size_t nested_offset;     /** offset from start of original fmap (data) for nested scan. 0 for orig fmap. */
-    size_t real_len;          /** len from start of original fmap (data) to end of current (possibly nested) map. */
-                              /* real_len == nested_offset + len.
-                                 real_len is needed for nested maps because we only reference the original mapping data.
-                                 We convert caller's fmap offsets & lengths to real data offsets using nested_offset & real_len. */
+    bool dont_cache_flag;  /** indicates if we should not cache scan results for this fmap. Used if limits exceeded */
+    uint16_t handle_is_fd; /** non-zero if map->handle is an fd. */
+    size_t offset;         /** file offset representing start of original fmap, if the fmap created reading from a file starting at offset other than 0 */
+    size_t nested_offset;  /** offset from start of original fmap (data) for nested scan. 0 for orig fmap. */
+    size_t real_len;       /** len from start of original fmap (data) to end of current (possibly nested) map. */
+                           /* real_len == nested_offset + len.
+                              real_len is needed for nested maps because we only reference the original mapping data.
+                              We convert caller's fmap offsets & lengths to real data offsets using nested_offset & real_len. */
 
     /* external */
     size_t len; /** length of data from nested_offset, accessible via current fmap */
@@ -84,8 +86,12 @@ struct cl_fmap {
     HANDLE fh;
     HANDLE mh;
 #endif
-    bool have_maphash;
-    unsigned char maphash[16];
+    bool have_md5;
+    unsigned char md5[CLI_HASHLEN_MD5];
+    bool have_sha1;
+    unsigned char sha1[CLI_HASHLEN_SHA1];
+    bool have_sha256;
+    unsigned char sha256[CLI_HASHLEN_SHA256];
     uint64_t *bitmap;
     char *name;
 };
@@ -426,14 +432,25 @@ cl_error_t fmap_dump_to_file(fmap_t *map, const char *filepath, const char *tmpd
 int fmap_fd(fmap_t *m);
 
 /**
- * @brief   Get a pointer to the fmap hash.
+ * @brief Get a pointer to the fmap hash.
  *
  * Will calculate the hash if not already previously calculated.
  *
  * @param map       The map in question.
  * @param[out] hash A pointer to the hash.
+ * @param type      The type of hash to calculate.
  * @return cl_error_t CL_SUCCESS if was able to get the hash, else some error.
  */
-cl_error_t fmap_get_MD5(fmap_t *map, unsigned char **hash);
+cl_error_t fmap_get_hash(fmap_t *map, unsigned char **hash, cli_hash_type_t type);
+
+/**
+ * @brief Set the hash for the fmap that was previously calculated.
+ *
+ * @param map       The map in question.
+ * @param hash      The hash to set.
+ * @param type      The type of hash to calculate.
+ * @return cl_error_t CL_SUCCESS if was able to set the hash, else some error.
+ */
+cl_error_t fmap_set_hash(fmap_t *map, unsigned char *hash, cli_hash_type_t type);
 
 #endif
