@@ -1,7 +1,7 @@
 /*
  *  Detect phishing, based on URL spoofing detection.
  *
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -211,6 +211,7 @@ static void url_check_init(struct url_check* urls)
     string_init_c(&urls->realLink, NULL);
     string_init_c(&urls->displayLink, NULL);
     string_init_c(&urls->pre_fixup.pre_displayLink, NULL);
+    urls->flags = 0;
 }
 
 /* string reference counting implementation,
@@ -264,7 +265,7 @@ static int string_assign_concatenated(struct string* dest, const char* prefix, c
         cli_errmsg("Phishcheck: Unable to allocate memory for string_assign_concatenated\n");
         return CL_EMEM;
     }
-    strncpy(ret, prefix, prefix_len);
+    strncpy(ret, prefix, prefix_len + end - begin + 1);
     strncpy(ret + prefix_len, begin, end - begin);
     ret[prefix_len + end - begin] = '\0';
     string_free(dest);
@@ -732,9 +733,6 @@ cl_error_t phishingScan(cli_ctx* ctx, tag_arguments_t* hrefs)
         goto done;
     }
 
-    if (!ctx->found_possibly_unwanted && !SCAN_ALLMATCHES)
-        *ctx->virname = NULL;
-
     for (i = 0; i < hrefs->count; i++) {
         struct url_check urls;
         enum phish_status phishing_verdict;
@@ -776,32 +774,32 @@ cl_error_t phishingScan(cli_ctx* ctx, tag_arguments_t* hrefs)
             case CL_PHISH_CLEAN:
                 continue;
             case CL_PHISH_NUMERIC_IP:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Phishing.Email.Cloaked.NumericIP");
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Phishing.Email.Cloaked.NumericIP");
                 break;
             case CL_PHISH_CLOAKED_NULL:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Phishing.Email.Cloaked.Null"); /*fakesite%01%00@fake.example.com*/
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Phishing.Email.Cloaked.Null"); /*fakesite%01%00@fake.example.com*/
                 break;
             case CL_PHISH_SSL_SPOOF:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Phishing.Email.SSL-Spoof");
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Phishing.Email.SSL-Spoof");
                 break;
             case CL_PHISH_CLOAKED_UIU:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Phishing.Email.Cloaked.Username"); /*http://banksite@fake.example.com*/
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Phishing.Email.Cloaked.Username"); /*http://banksite@fake.example.com*/
                 break;
             case CL_PHISH_HASH0:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Safebrowsing.Suspected-malware_safebrowsing.clamav.net");
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Safebrowsing.Suspected-malware_safebrowsing.clamav.net");
                 break;
             case CL_PHISH_HASH1:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Phishing.URL.Blocked");
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Phishing.URL.Blocked");
                 break;
             case CL_PHISH_HASH2:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Safebrowsing.Suspected-phishing_safebrowsing.clamav.net");
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Safebrowsing.Suspected-phishing_safebrowsing.clamav.net");
                 break;
             case CL_PHISH_NOMATCH:
             default:
-                status = cli_append_possibly_unwanted(ctx, "Heuristics.Phishing.Email.SpoofedDomain");
+                status = cli_append_potentially_unwanted(ctx, "Heuristics.Phishing.Email.SpoofedDomain");
                 break;
         }
-        if (CL_CLEAN != status && !SCAN_ALLMATCHES) {
+        if (CL_SUCCESS != status) {
             goto done;
         }
     }
