@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Nigel Horne
@@ -138,7 +138,6 @@ cl_error_t cli_untar(const char *dir, unsigned int posix, cli_ctx *ctx)
     size_t pos      = 0;
     size_t currsize = 0;
     char zero[BLOCKSIZE];
-    unsigned int num_viruses = 0;
 
     cli_dbgmsg("In untar(%s)\n", dir);
     memset(zero, 0, sizeof(zero));
@@ -173,15 +172,15 @@ cl_error_t cli_untar(const char *dir, unsigned int posix, cli_ctx *ctx)
 
             if (fout >= 0) {
                 lseek(fout, 0, SEEK_SET);
-                ret = cli_magic_scan_desc(fout, fullname, ctx, name);
+                ret = cli_magic_scan_desc(fout, fullname, ctx, name, LAYER_ATTRIBUTES_NONE);
                 close(fout);
-                if (!ctx->engine->keeptmp)
-                    if (cli_unlink(fullname)) return CL_EUNLINK;
-                if (ret == CL_VIRUS) {
-                    if (!SCAN_ALLMATCHES)
-                        return CL_VIRUS;
-                    else
-                        num_viruses++;
+                if (!ctx->engine->keeptmp) {
+                    if (cli_unlink(fullname)) {
+                        return CL_EUNLINK;
+                    }
+                }
+                if (ret != CL_SUCCESS) {
+                    return ret;
                 }
                 fout = -1;
             }
@@ -304,10 +303,7 @@ cl_error_t cli_untar(const char *dir, unsigned int posix, cli_ctx *ctx)
             strncpy(name, block, 100);
             name[100] = '\0';
             if (cli_matchmeta(ctx, name, size, size, 0, files, 0, NULL) == CL_VIRUS) {
-                if (!SCAN_ALLMATCHES)
-                    return CL_VIRUS;
-                else
-                    num_viruses++;
+                return CL_VIRUS;
             }
 
             snprintf(fullname, sizeof(fullname) - 1, "%s" PATHSEP "tar%02u", dir, files);
@@ -369,14 +365,17 @@ cl_error_t cli_untar(const char *dir, unsigned int posix, cli_ctx *ctx)
     }
     if (fout >= 0) {
         lseek(fout, 0, SEEK_SET);
-        ret = cli_magic_scan_desc(fout, fullname, ctx, name);
+        ret = cli_magic_scan_desc(fout, fullname, ctx, name, LAYER_ATTRIBUTES_NONE);
         close(fout);
-        if (!ctx->engine->keeptmp)
-            if (cli_unlink(fullname)) return CL_EUNLINK;
-        if (ret == CL_VIRUS)
-            return CL_VIRUS;
+        if (!ctx->engine->keeptmp) {
+            if (cli_unlink(fullname)) {
+                return CL_EUNLINK;
+            }
+        }
+        if (ret != CL_SUCCESS) {
+            return ret;
+        }
     }
-    if (num_viruses)
-        return CL_VIRUS;
+
     return CL_CLEAN;
 }
